
.. currentmodule:: sardana.macroserver.macros.test

.. _sardana-test-howto:

===============
Sardana Testing
===============


.. toctree::
    :maxdepth: 2
    
    General test documentation <test_general>
    Run Sardana tests from command line <test_run_commands>
    Test-driven development example <test_example>
    Sardana Unit Test examples <tests/index>
